**********************************************************
* Introduzione all'analisi dei dati longitudinali
* CAP 4:	ANALISI DEI DATI PANEL  
**********************************************************
* questa sintassi: 
* panel_intro.do
* VERSIONE: AGOSTO 2013
*********************************************
** esempio tratto da K & K (2005, 2012 nella 3a edizione ). 

* INTRODUZIONE *
*version 12.1 
capture log close
set logtype text 
global pa "F:\longi" 


use $pa\data\beatles.dta, clear
log using $pa\panel\panel_intro.log, replace


rename persnr pid
*una variabile dicotomica per la soddisfazione di vita:  1=soddisfatto 0= no
gen sat01=lsat>5
tab sat01

di in red "1.	STRUTTURA DEI DATI " 
sort pid  time 

**generazione medie BG e WG

di in red "2.	APPROCCIO GRAFICO  " 
egen mlsat_BG=mean(lsat), by(pid)
egen mage_BG=mean(age), by(pid)
egen mlsat_WG=mean(lsat), by(time)
egen mage_WG=mean(age), by(time)

* BETWEEN EFFECTS (between persons) 
di in red "BETWEEN EFFECTS"
tw ///
|| sc lsat age, mlab(pid) ms(oh) ///
|| sc mlsat_BG mage_BG, ms(o) mcolor(black) ///
|| lfit mlsat_BG mage_BG ///
|| , legend(off) /// 
title("BETWEEN EFFECTS") ///
plotregion(margin(large)) graphregion(color(gs14)) ///
ytitle("Life Satisfaction") xtitle("Age")


** WITHIN = FIXED EFFECT (within persons)
di in red "WITHIN EFFECTS"
tw ///
|| sc lsat age, mlab(pid) ms(oh) ///
|| sc mlsat_WG mage_WG, ms(o) mcolor(black) ///
|| lfit mlsat_WG mage_WG ///
|| , legend(off) ///
title("WITHIN (FIXED) EFFECTS") ///
plotregion(margin(large)) graphregion(color(gs14)) ///
ytitle("Life Satisfaction") xtitle("Age")


di in red  "3.	DESCRITTIVE" 
* xtset dichara la struttura dei dati che rimane in memoria
xtset pid time
xtsum lsat
loneway lsat pid // ICC ==0,66
xtreg lsat // ICC==RHO==0,66

xttab sat01
xttrans sat01

* generazione nuove variabili utilizzando l'info longitudinale 
* attenzione al fatto che i dati siano ordinati nel modo giusto 
* vedi sopra: sort pid  time 
* un contatore
bys pid: gen nr=_n
* il valore laged 
gen lag_lsat= lsat[_n-1] if pid == pid[_n-1] 
* la differenza da t1 a t2 
gen dif_var =  lsat - lsat[_n-1] if pid == pid[_n-1]  

* generazione contatore, ad esempio delle osservazioni in cui i soggetti esprimono alti livelli di soddifazione

bys pid: gen count_sat = sum(sat01)
*in alternativa : 
*gen count_sat2=sat01
*replace count_sat2=count_sat2[_n-1]+ count_sat2 if pid == pid[_n-1]  
*in alternativa : 
*gen count_sat3=0 
*by pid: replace count_sat3= sat01 if [_n]==1 
*by pid: replace count_sat3= count_sat3[_n-1] + sat01 if [_n] >1
browse 

///*** QUESTO MATIERIALE NON E' TRATTATO NEL LIBRO***\\\
di in red  "4.	MODELLI" 

* BETWEEN  EFFECTS MODEL 
di in red "BETWEEN EFFECT"  

* modello panel  BE 
xtreg lsat age, i(pid) be
* a mano
collapse (mean) lsat age, by(pid)
reg lsat age 

**"effetti" positivi (distorti) dell'et sulla soddifazione**

**RIPRISTINO DATI E STIME WITHIN**
di in red "WITHIN EFFECT"  
use $pa\data\beatles.dta, clear
rename persnr pid
xtset pid time
*modello panel   FE
xtreg lsat age, fe 
*a mano
reg lsat age i.pid

**effetto negativo, (corretto) dell'et sulla soddisfazione; differenze individuali controllate mediante singole dummy o eliminate dal confronti WG**

*STIMA RE, random intercept model* 
di in red "RANDOM MODEL" 
xtreg lsat age, theta re  

**pesando varianza WG e BG, le stime derivanti da RE cadono nell'intervallo delle stime che usano unicamente una fonte di varianza*
*in questo caso, il peso preponderante (circa 3/4)  dato alla varianza WG; in effetti, anche  il RE restituisce per l'effetto et una stima negativa
* uno stimatore pi efficiente, e tuttavia distorto in mancanza di supporto per l'assunzione corr(X,u)=0 


* Hausman Test (1) stima RE e salvataggio risultati, 2) stima FE e salvataggio risultati 3) test chi^2)
xtreg lsat age, fe
est store fixeff
xtreg lsat age, re
est store raneff
hausman fixeff raneff, sigmamore

*il segno nell'effetto della variabile d'interesse  lo stesso, tuttavia le stime ottenute con RE e FE si discostano significativamente: 
* va adottata la specificazione FE. 


* 4 regressioni within individuali  
* "curve di crescita" a mano*
qui: bys pid: reg lsat age 

tw ///
|| sc lsat age, mlab(pid) ms(oh) ///
|| lfit lsat age if pid==1 ///
|| lfit lsat age if pid==2 ///
|| lfit lsat age if pid==3 ///
|| lfit lsat age if pid==4 ///
|| , legend(off) 


